@@ -1,5 +1,5 @@
 # -*- mode: python; coding: utf-8 -*-
-# Copyright 2014 Peter Williams <peter@newton.cx> and collaborators.
+# Copyright 2014-2015 Peter Williams <peter@newton.cx> and collaborators.
 # Licensed under the MIT License.
 
 """
@@ -29,6 +29,7 @@ Modules in this package:
   msmt             - Framework for working with uncertain measurements.
   ndshow_gtk2      - Visualize data arrays as interactive images, using Gtk+2.
   numutil          - Basic NumPy and generic numerical utilities.
+  parallel         - Utilities for parallel processing.
   pdm              - Finding periods in data with Phase Dispersion Minimization.
   phoenix          - Working with Phoenix-based model atmospheres.
   radio_cal_models - Models of radio-wavelength calibrator flux densities.
@@ -38,13 +39,26 @@ Modules in this package:
   ucd_physics      - Estimating physical quantities for M stars and UCDs.
   unicode_to_latex - Rendering Unicode to LaTeX.
 
+
+Classes in the toplevel module:
+
+Holder      - A "namespace object" that just lets you assign attributes.
+PKError     - Base exception class for PWKit
+binary_type - The binary data type: either `str` (Python 2.x) or `bytes` (Python 3.x)
+text_type   - The binary data type: either `unicode` (Python 2.x) or `str` (Python 3.x)
+
+Functions in the toplevel module:
+
+reraise_context - Reraise an exception with additional contextual information in the message.
+unicode_to_str  - Write `def __unicode__ (self): ... ; __str__ = unicode_to_str` in classes.
+
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 __all__ = (b'Holder PKError binary_type reraise_context text_type '
            b'unicode_to_str').split ()
 
-__version__ = '0.2.0'
+__version__ = '0.3.0' # also edit ../setup.py!
 
 # Lightly-exercised simultaneous Python 2 and 3 compat.
 import sys
@@ -92,8 +106,49 @@ def reraise_context (fmt, *args):
 
 
 class Holder (object):
-    def __init__ (self, **kwargs):
-        self.set (**kwargs)
+    """A basic 'namespace class' that provides you a place to easily stick named
+    data with a minimum of fuss.
+
+    Holder (name1=val1, name2=val2, ...)
+
+    Provides nice str/unicode/repr representations, and basic manipulations:
+
+    set(**kwargs)           - Set named keys as a group
+    setone (name, value)    - Set a specific key
+    get (name, defval=None) - Retrieve a key with an optional default
+    copy ()                 - Make a shallow clone of the Holder
+
+    This class may also be used as a decorator on a class definition to transform
+    its contents into a Holder instance. Writing:
+
+        @Holder
+        class mydata ():
+            a = 1
+            b = 'hello'
+
+    creates a Holder instance named 'mydata' containing names 'a' and 'b'.
+    This can be a convenient way to populate one-off data structures.
+
+    """
+    def __init__ (self, __decorating=None, **kwargs):
+        import types
+
+        if __decorating is None:
+            values = kwargs
+        elif isinstance (__decorating, (type, types.ClassType)):
+            # We're decorating a class definition. Transform the definition
+            # into a Holder instance thusly:
+            values = dict (kv for kv in __decorating.__dict__.iteritems ()
+                           if not kv[0].startswith ('__'))
+        else:
+            # You could imagine allowing @Holder on a function and doing
+            # something with its return value, but I can't think of a use that
+            # would be more sensible than just creating and returning a Holder
+            # directly.
+            raise ValueError ('unexpected use of Holder as a decorator (on %r)'
+                              % __decorating)
+
+        self.set (**values)
 
     def __unicode__ (self):
         d = self.__dict__
