@@ -37,7 +37,7 @@ print (reg.telescopes ()) # list known telescopes
 print (reg.bands ('2MASS')) # list known 2MASS bands
 bp = reg.get ('2MASS', 'Ks')
 mag = 12.83
-mjy = pm.repval (bp.mag_to_fnu (12.83) * pc.jypercgs * 1e3)
+mjy = pm.repval (bp.mag_to_fnu (mag) * pc.jypercgs * 1e3)
 print ('%.2f mag is %.2f mjy in 2MASS/Ks' % (mag, mjy))
 
 
@@ -71,6 +71,15 @@ half-maximum points (in the EE convention) to define the band edges.
 This module requires Scipy and Pandas. It doesn't reeeeallllly need Pandas but
 it's convenient.
 
+References
+----------
+
+Casagrande & VandenBerg (2014; arxiv:1407.6095) has a lot of good stuff; see
+  also references therein.
+
+References for specific bandpasses are given in their implementation
+docstrings.
+
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
 
@@ -501,6 +510,11 @@ class TwomassBandpass (Bandpass):
 def register_2mass (reg):
     reg.register_bpass ('2MASS', TwomassBandpass)
 
+    # Computed myself from the filter response curves.
+    reg.register_pivot_wavelength ('2MASS', 'J', 12371.)
+    reg.register_pivot_wavelength ('2MASS', 'H', 16457.)
+    reg.register_pivot_wavelength ('2MASS', 'Ks', 21603.)
+
     # Computed from filter responses using interpolator.
     reg.register_halfmaxes ('2MASS', 'J', 11316., 13465.)
     reg.register_halfmaxes ('2MASS', 'H', 15182., 17792.)
@@ -653,6 +667,13 @@ class MearthBandpass (Bandpass):
         were fundamentally made by reading points off of data sheets so
         they're not going to be the most accurate.
 
+        I computed the filter response file myself by multiplying spline
+        approximations to the CCD and RG715 response curves emailed to me by
+        Jonathan Irwin on 2014 Jul 11. I should write up something explaining
+        what I did for posterity/reproducibility. AFAIK the response curves
+        aren't published anywhere besides a hard-to-read plot in Nutzman &
+        Charbonneau (2008).
+
         """
         df = bandpass_data_frame ('filter_mearth_' + band + '.dat', 'wlen resp')
         df.resp *= df.wlen # QE to equal-energy response.
@@ -711,7 +732,6 @@ class MkoBandpass (Bandpass):
         Vega = 0.
 
         """
-
         return cgs.cgsperjy * self._zeropoints[self.band] * 10**(-0.4 * mag)
 
 
